@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "المواعيد",
     "Schedule appointment \"%s\"" : "جدولة الموعد \"%s\"",
     "Schedule an appointment" : "جدولة موعد",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "تحضير لـ %s",
     "Follow up for %s" : "متابعة لـ %s",
     "Your appointment \"%s\" with %s needs confirmation" : "موعدك \"%s\" مع %s يحتاج إلى توكيد.",
@@ -64,6 +63,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "تعذّر نسخ رابط الموعد في الحافظة",
     "Preview" : "معاينة",
     "Copy link" : "نسخ الرابط",
+    "Duplicate" : "تكرار",
     "Edit" : "تعديل",
     "Delete" : "حذف ",
     "Appointment schedules" : "جداول المواعيد",
@@ -73,8 +73,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "تمكين التقويم \"{calendar}\"",
     "Enable untitled calendar" : "تمكين التقويم بدون اسم",
     "An error occurred, unable to change visibility of the calendar." : "حدث خطأ، لا يمكن تعديل وضعية ظهور التقويم.",
+    "Calendar link copied to clipboard." : "تم نسخ رابط التقويم إلى الحافظة.",
+    "Calendar link could not be copied to clipboard." : "تعذّر نسخ رابط التقويم إلى الحافظة.",
     "Untitled calendar" : "تقويم بدون اسم",
     "Shared with you by" : "مشاركة معك من قِبَل",
+    "Copy public link" : "نسخ الرابط العام",
     "Edit and share calendar" : "تعديل ومشاركة التقويم",
     "Edit calendar" : "تعديل التقويم",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثانية","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني","إلغاء مشاركة التقويم في {countdown} ثواني"],
@@ -91,8 +94,6 @@ OC.L10N.register(
     "Creating subscription …" : "جارٍ إنشاء اشتراك…",
     "Add public holiday calendar" : "أضف تقويم العطلات العامة",
     "Add custom public calendar" : "إضافة تقويم عام مخصّص",
-    "Calendar link copied to clipboard." : "تم نسخ رابط التقويم إلى الحافظة.",
-    "Calendar link could not be copied to clipboard." : "تعذّر نسخ رابط التقويم إلى الحافظة.",
     "Copy subscription link" : "نسخ رابط الاشتراك",
     "Copying link …" : "جارٍ نسخ رابط  …",
     "Copied link" : "تمّ نسخ الرابط",
@@ -125,7 +126,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "الكود المُضمّن تعذّر نسخه إلى الحافظة",
     "Unpublishing calendar failed" : "محاولة إلغاء نشر التقويم أخفقت",
     "Share link" : "رابط مشاركة",
-    "Copy public link" : "نسخ الرابط العام",
     "Send link to calendar via email" : "إرسال رابط التقويم عبر الإيمل",
     "Enter one address" : "أدخِل عنواناً بريدياً واحداً",
     "Sending email …" : "جارٍ إرسال البريد  …",
@@ -190,15 +190,12 @@ OC.L10N.register(
     "At event start" : "في بداية الحدث",
     "No reminder" : "لا يوجد تذكير ",
     "Failed to save default calendar" : "تعذّر حفظ التقويم التلقائي",
-    "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
-    "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
     "General" : "عامٌّ",
-    "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
+    "Default calendar for incoming invitations" : "التقويم التلقائي للدعوات الواردة",
     "Appearance" : "المظهر",
     "Editing" : "جارِ التعديل",
-    "Default calendar for incoming invitations" : "التقويم التلقائي للدعوات الواردة",
     "Default reminder" : "التذكير الافتراضي",
-    "Keyboard shortcuts" : "اختصارات لوحة المفاتيح",
+    "Files" : "الملفّات",
     "Appointment schedule successfully created" : "تمّ إنشاء جدول المواعيد بنجاح",
     "Appointment schedule successfully updated" : "تمّ تحديث جدول المواعيد بنجاح",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} دقائق","{duration} دقيقة","{duration} دقائق","{duration} دقائق","{duration} دقائق","{duration} دقائق"],
@@ -215,6 +212,7 @@ OC.L10N.register(
     "Create appointment schedule" : "إنشاء جدول مواعيد",
     "Edit appointment schedule" : "تعديل جدول المواعيد",
     "Update" : "حدث",
+    "(copy)" : "(نسخ)",
     "Appointment name" : "اسم الموعد",
     "Location" : "الموقع",
     "Create a Talk room" : "إنشاء غرفة محادثة",
@@ -258,14 +256,15 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "تمت إضافة رابط المحادثة إلى الموقع بنجاح.",
     "Successfully added Talk conversation link to description." : "تمت إضافة رابط المحادثة إلى الوصف بنجاح.",
     "Failed to apply Talk room." : "تعذّر تطبيق غرفة المحادثة.",
+    "Talk conversation for event" : "محادثة الحدث ",
     "Error creating Talk conversation" : "خطأ في إنشاء رابط المحادثة",
     "Select a Talk Room" : "إختَر غرفة المحادثة",
-    "Add Talk conversation" : "إضِف محادثة Talk",
     "Fetching Talk rooms…" : "جلب معلومات غرف المحادثة ...",
     "No Talk room available" : "لاتوجد غرف محادثة متاحة",
     "Select conversation" : "اختر محادثة",
     "on" : "في",
     "at" : "عند",
+    "Amount" : "الكمية",
     "before at" : "قبل",
     "Notification" : "تنبيه",
     "Email" : "البريد الإلكتروني",
@@ -339,10 +338,8 @@ OC.L10N.register(
     "Accept" : "قبول",
     "Decline" : "رفض",
     "Tentative" : "مؤقت",
+    "Copied to clipboard" : "تمّ النسخ إلى الحافظة",
     "No attendees yet" : "لا يوجد حضور حتى الآن",
-    "Successfully appended link to talk room to location." : "تمّ إلحاق رابط غرفة المحادثة بالموقع بنجاح.",
-    "Successfully appended link to talk room to description." : "تمّ إلحاق الرابط بوصف غرفة المحادثة بنجاح.",
-    "Error creating Talk room" : "خطأ في انشاء غرفة محادثة",
     "Attendees" : "المشاركون",
     "Remove group" : "حذف مجموعة",
     "Remove attendee" : "إلغاء شخص من قائمة الحضور",
@@ -361,17 +358,15 @@ OC.L10N.register(
     "Make {label} the organizer and attend" : "إجغعَل {label} هو المنظم و أحد الحضور",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "لإرسال الدعوات والتعامل مع الاستجابات [linkopen]، أضف بريدك الالكتروني في الإعدادات الشخصية [linkclose].",
     "Remove color" : "حذف لون",
-    "Event title" : "عنوان الحدث",
+    "Title" : "العنوان",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "لم يُمكن تغيير إعداد \"كامل اليوم\" بالنسبة للأحداث التي هي جزء من مجموعة تكرارية. ",
     "From" : "مِن :",
     "To" : "إلى :",
     "Repeat" : "كرّر",
-    "_time_::_times_" : ["مرات","مرة","مرات","مرات","مرات","مرات"],
     "never" : "أبداً",
     "on date" : "في تاريخ",
     "after" : "بعد",
     "End repeat" : "نهاية التكرار",
-    "Select to end repeat" : "إختر نهاية التكرار",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "هذا الحدث هو استثناء من مجموعة التكرار. لا يمكنك إضافة شرط تكرار إليه.",
     "first" : "أول",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "التغيير في قاعدة التكرار سوف يُطبّق فقط على هذا التكرار و على التكرارات المستقبلية.",
@@ -414,19 +409,6 @@ OC.L10N.register(
     "Maybe" : "ربما",
     "None" : "لا شيء",
     "Create" : "إنشاء",
-    "from {formattedDate}" : "من {formattedDate}",
-    "to {formattedDate}" : "إلى {formattedDate}",
-    "on {formattedDate}" : "في {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "من {formattedDate} عند {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "إلى {formattedDate} عند {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "في {formattedDate} عند {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} عند {formattedTime}",
-    "Please enter a valid date" : "إختر تاريخاً صحيحاً",
-    "Please enter a valid date and time" : "إختر تاريخاً و وقتاً صحيحاً",
-    "Select a time zone" : "إختر المنطقة الزمنية",
-    "Please select a time zone:" : "إختر المنطقة الزمنية من فضلك:",
-    "Pick a time" : "إختر وقتاً",
-    "Pick a date" : "إختر تاريخاً",
     "Type to search time zone" : "أكتب للبحث في المنطقة الزمنية ",
     "Global" : "عالمي",
     "Holidays in {region}" : "العطلات الرسمية في {region}",
@@ -459,13 +441,14 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "الاكتشاف التلقائي للمنطقة الزمنية يُحدّد منطقتك الزمنية بالنسبة للتوقيت العالمي المُوحّد UTC. هذا على الأرجح نتيجة للتدابير الأمنية لمتصفح الويب الخاص بك. يُرجى ضبط المنطقة الزمنية يدويًا في إعدادات التقويم.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "لم يتم العثور على منطقتك الزمنية التي تمّت تهيئتها ({timezoneId}). تمّ الرجوع إلى التوقيت العالمي المُوحّد UTC. يرجى تغيير منطقتك الزمنية في الإعدادات، والإبلاغ عن هذه المشكلة.",
     "Availability of {displayName}" : "توافُر {displayName}",
+    "Discard changes" : "تجاهل التغييرات",
     "Edit event" : "تعديل الحدث",
     "Event does not exist" : "الفعالية غير موجودة",
-    "Duplicate" : "تكرار",
     "Delete this occurrence" : "حذف هذا الظهور",
     "Delete this and all future" : "حذف هذا الظهور والجميع في الستقبل",
     "All day" : "كامل اليوم",
     "Modifications wont get propagated to the organizer and other attendees" : "التعديلات لن يتم إذاعتها على المنظم والمشاركين الآخرين",
+    "Add Talk conversation" : "إضِف محادثة Talk",
     "Managing shared access" : "إدارة الوصول المشترك",
     "Deny access" : "منع الوصول",
     "Invite" : "دعوة",
@@ -474,9 +457,8 @@ OC.L10N.register(
     "Untitled event" : "حدث بدون اسم",
     "Close" : "إغلاق",
     "Modifications will not get propagated to the organizer and other attendees" : "التعديلات لن يتم إذاعتها على المنظم والمشاركين الآخرين",
+    "This event was cancelled" : "الحدثُ تمّ إلغاؤه",
     "Selected" : "مُحدّدة",
-    "Title" : "العنوان",
-    "30 min" : "30 دقيقة",
     "Participants" : "المشارِكون",
     "Submit" : "إرسال ",
     "Subscribe to {name}" : "اشتراك مع {name}",
@@ -543,8 +525,8 @@ OC.L10N.register(
     "_+%n more_::_+%n more_" : ["+ %n أكثر","+ %n أكثر","+ %n أكثر","+ %n أكثر","+ %n أكثر","+ %n أكثر"],
     "No events" : "لا توجد أحداث",
     "Create a new event or change the visible time-range" : "أنشيء حدثاً جديداً أو قم بتغيير المدى الزمني",
-    "Failed to save event" : "تعذّر حفظ الحدث",
     "It might have been deleted, or there was a typo in a link" : "لربما تمّ حذفها، أو كان هناك خطأٌ هجائي في الرابط",
+    "Failed to save event" : "تعذّر حفظ الحدث",
     "It might have been deleted, or there was a typo in the link" : "لربما تمّ حذفها، أو كان هناك خطأٌ هجائي في الرابط",
     "Meeting room" : "غرفة اجتماعات",
     "Lecture hall" : "قاعة محاضرات",
@@ -572,19 +554,21 @@ OC.L10N.register(
     "Error while sharing file with user" : "حدث خطأ أثناء مُشاركة الملف مع مُستخدِم",
     "Attachment {fileName} already exists!" : "المُرفَق {fileName} موجودٌ سلفاً!",
     "An error occurred during getting file information" : "حدث خطأ أثناء جلب بيانات الملف",
-    "Talk conversation for event" : "محادثة الحدث ",
     "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
     "Imported {filename}" : "إستيراد {filename}",
     "This is an event reminder." : "هذا تذكير بحدث",
     "Error while parsing a PROPFIND error" : "حدث خطأ أثناء تحليل PROFIND",
     "Appointment not found" : "الموعد غير موجود",
     "User not found" : "المستخدم غير موجود",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "مخفي",
     "can edit" : "يمكن التحرير",
     "Calendar name …" : "اسم التقويم ...",
     "Default attachments location" : "موقع المُرفقات التلقائي",
     "Automatic ({detected})" : "تلقائي ({detected})",
     "Shortcut overview" : "نظرة عامة للاختصارات",
+    "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
+    "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
     "Enable birthday calendar" : "تفعيل تقويم عيد الميلاد",
     "Show tasks in calendar" : "إظهار المهام في التقويم",
     "Enable simplified editor" : "تفعيل المحرر البسيط",
@@ -593,10 +577,31 @@ OC.L10N.register(
     "Show week numbers" : "إظهار أرقام الأسابيع",
     "Time increments" : "زيادات الوقت",
     "Copy primary CalDAV address" : "نسخ عنوان CalDAV الرئيسي",
+    "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
     "Personal availability settings" : "إعدادات التواجد الشخصي",
     "Show keyboard shortcuts" : "إظهار اختصارات لوحة المفاتيح",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} مدعو, {confirmedCount} مؤكد",
+    "Successfully appended link to talk room to location." : "تمّ إلحاق رابط غرفة المحادثة بالموقع بنجاح.",
+    "Successfully appended link to talk room to description." : "تمّ إلحاق الرابط بوصف غرفة المحادثة بنجاح.",
+    "Error creating Talk room" : "خطأ في انشاء غرفة محادثة",
     "_%n more guest_::_%n more guests_" : ["%n ضيفاً آخر","%n ضيفاً آخر","%n ضيفاً آخر","%n ضيوف آخرين","%n ضيفاً آخر","%n ضيفاً آخر"],
-    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة."
+    "Event title" : "عنوان الحدث",
+    "_time_::_times_" : ["مرات","مرة","مرات","مرات","مرات","مرات"],
+    "Select to end repeat" : "إختر نهاية التكرار",
+    "from {formattedDate}" : "من {formattedDate}",
+    "to {formattedDate}" : "إلى {formattedDate}",
+    "on {formattedDate}" : "في {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "من {formattedDate} عند {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "إلى {formattedDate} عند {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "في {formattedDate} عند {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} عند {formattedTime}",
+    "Please enter a valid date" : "إختر تاريخاً صحيحاً",
+    "Please enter a valid date and time" : "إختر تاريخاً و وقتاً صحيحاً",
+    "Select a time zone" : "إختر المنطقة الزمنية",
+    "Please select a time zone:" : "إختر المنطقة الزمنية من فضلك:",
+    "Pick a time" : "إختر وقتاً",
+    "Pick a date" : "إختر تاريخاً",
+    "The visibility of this event in shared calendars." : "ظهور الحدث في التقاويم المشتركة.",
+    "30 min" : "30 دقيقة"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
