@@ -189,6 +189,7 @@ OC.L10N.register(
     "No reminder" : "Sense recordatoris",
     "Failed to save default calendar" : "No s'ha pogut desar el calendari predeterminat",
     "General" : "General",
+    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
     "Appearance" : "Aparença",
     "Editing" : "Edició",
     "Default reminder" : "Recordatori per defecte",
@@ -261,6 +262,7 @@ OC.L10N.register(
     "Select conversation" : "Seleccioneu una conversa",
     "on" : "a",
     "at" : "a",
+    "Amount" : "Quantitat",
     "before at" : "abans a les",
     "Notification" : "Notificació",
     "Email" : "Correu",
@@ -354,17 +356,15 @@ OC.L10N.register(
     "Make {label} the organizer and attend" : "Feu que {label} sigui l'organitzador i assistent",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Per enviar invitacions i atendre les respostes, cal que [linkopen]afegiu la vostra adreça de correu a la vostra configuració personal[linkclose].",
     "Remove color" : "Suprimeix el color",
-    "Event title" : "Títol de l'esdeveniment",
+    "Title" : "Títol",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "No es pot modificar la configuració de tot el dia per als esdeveniments que formen part d'un conjunt de recurrència.",
     "From" : "De",
     "To" : "A",
     "Repeat" : "Repeteix",
-    "_time_::_times_" : ["vegada","vegades"],
     "never" : "mai",
     "on date" : "el dia",
     "after" : "després de",
     "End repeat" : "Finalitza la repetició",
-    "Select to end repeat" : "Seleccioneu per finalitzar repetició",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Aquest esdeveniment és l'excepció de recurrència d'un conjunt de recurrència. No hi podeu afegir una regla de recurrència.",
     "first" : "primer",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Els canvis a la regla de recurrència només afectarà en aquesta i futures ocurrències.",
@@ -408,19 +408,6 @@ OC.L10N.register(
     "Maybe" : "Potser",
     "None" : "Només una vegada",
     "Create" : "Crea",
-    "from {formattedDate}" : "de {formattedDate}",
-    "to {formattedDate}" : "a {formattedDate}",
-    "on {formattedDate}" : "el {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "del {formattedDate} a les {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "al {formattedDate} a les {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a les {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} a les {formattedTime}",
-    "Please enter a valid date" : "Indiqueu una data vàlida",
-    "Please enter a valid date and time" : "Indiqueu una data i hora vàlides",
-    "Select a time zone" : "Seleccioneu una zona horària",
-    "Please select a time zone:" : "Seleccioneu una zona horària:",
-    "Pick a time" : "Tria una hora",
-    "Pick a date" : "Tria una data",
     "Type to search time zone" : "Escriviu per cercar la zona horària",
     "Global" : "Global",
     "Holidays in {region}" : "Festius a {region}",
@@ -471,8 +458,6 @@ OC.L10N.register(
     "Modifications will not get propagated to the organizer and other attendees" : "Les modificacions no es propagaran a l'organitzador i als altres assistents",
     "This event was cancelled" : "Aquest esdeveniment s'ha cancel·lat",
     "Selected" : "Seleccionat",
-    "Title" : "Títol",
-    "30 min" : "30 min",
     "Participants" : "Participants",
     "Submit" : "Envia",
     "Subscribe to {name}" : "Subscriure a {name}",
@@ -539,8 +524,8 @@ OC.L10N.register(
     "_+%n more_::_+%n more_" : ["i %n més","i %n més"],
     "No events" : "Cap esdeveniment",
     "Create a new event or change the visible time-range" : "Crea un esdeveniment nou o canvia l'interval de temps visible",
-    "Failed to save event" : "No s'ha pogut desar l'esdeveniment",
     "It might have been deleted, or there was a typo in a link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic en un enllaç",
+    "Failed to save event" : "No s'ha pogut desar l'esdeveniment",
     "It might have been deleted, or there was a typo in the link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic a l'enllaç",
     "Meeting room" : "Sala de reunions",
     "Lecture hall" : "Sala de lectura",
@@ -590,7 +575,6 @@ OC.L10N.register(
     "Show weekends" : "Mostra els caps de setmana",
     "Show week numbers" : "Mostra el número de la setmana",
     "Time increments" : "Increments de temps",
-    "Default calendar for incoming invitations" : "Calendari predeterminat per a les invitacions entrants",
     "Copy primary CalDAV address" : "Copia l'adreça CalDAV primària",
     "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
     "Personal availability settings" : "Paràmetres de disponibilitat personal",
@@ -600,6 +584,23 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "S'ha afegit l'enllaç d'una nova sala de Talk a la descripció de l'esdeveniment.",
     "Error creating Talk room" : "Ha succeït un error tractant de crear la sala a Talk",
     "_%n more guest_::_%n more guests_" : ["%n convidat més","%n convidats més"],
-    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits."
+    "Event title" : "Títol de l'esdeveniment",
+    "_time_::_times_" : ["vegada","vegades"],
+    "Select to end repeat" : "Seleccioneu per finalitzar repetició",
+    "from {formattedDate}" : "de {formattedDate}",
+    "to {formattedDate}" : "a {formattedDate}",
+    "on {formattedDate}" : "el {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "del {formattedDate} a les {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "al {formattedDate} a les {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a les {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} a les {formattedTime}",
+    "Please enter a valid date" : "Indiqueu una data vàlida",
+    "Please enter a valid date and time" : "Indiqueu una data i hora vàlides",
+    "Select a time zone" : "Seleccioneu una zona horària",
+    "Please select a time zone:" : "Seleccioneu una zona horària:",
+    "Pick a time" : "Tria una hora",
+    "Pick a date" : "Tria una data",
+    "The visibility of this event in shared calendars." : "La visibilitat de l'event en calendaris compartits.",
+    "30 min" : "30 min"
 },
 "nplurals=2; plural=(n != 1);");
