@@ -231,6 +231,7 @@ OC.L10N.register(
     "Select conversation" : "Seleccionar conversación",
     "on" : "el",
     "at" : "a las",
+    "Amount" : "Cantidad",
     "before at" : "antes a las",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
@@ -300,17 +301,15 @@ OC.L10N.register(
     "(organizer)" : "(organizador)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar invitaciones y manejar respuestas, [linkopen]agrega tu dirección de correo electrónico en la configuración personal[linkclose].",
     "Remove color" : "Eliminar color",
-    "Event title" : "Título del evento",
+    "Title" : "Título",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar la configuración de todo el día para eventos que forman parte de un conjunto de repeticiones.",
     "From" : "De",
     "To" : "A",
     "Repeat" : "Repetir",
-    "_time_::_times_" : ["hora","veces","veces"],
     "never" : "nunca",
     "on date" : "en la fecha",
     "after" : "después",
     "End repeat" : "Finalizar repetición",
-    "Select to end repeat" : "Seleccionar para finalizar la repetición",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento es una excepción de la recurrencia de un conjunto de repeticiones. No puedes agregar una regla de recurrencia a él.",
     "first" : "primero",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Los cambios en la regla de recurrencia solo se aplicarán a esta y a todas las siguientes ocurrencias.",
@@ -348,18 +347,6 @@ OC.L10N.register(
     "Maybe" : "Tal vez",
     "None" : "Ninguno",
     "Create" : "Crear",
-    "from {formattedDate}" : "desde {formattedDate}",
-    "to {formattedDate}" : "hasta {formattedDate}",
-    "on {formattedDate}" : "el {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} a las {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "hasta {formattedDate} a las {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a las {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} a las {formattedTime}",
-    "Please enter a valid date" : "Ingresa una fecha válida",
-    "Please enter a valid date and time" : "Ingresa una fecha y hora válidas",
-    "Please select a time zone:" : "Selecciona una zona horaria:",
-    "Pick a time" : "Seleccionar una hora",
-    "Pick a date" : "Selecciona una fecha",
     "Type to search time zone" : "Escribe para buscar la zona horaria",
     "Global" : "Global",
     "Holidays in {region}" : "Vacaciones en {región}",
@@ -398,8 +385,6 @@ OC.L10N.register(
     "Untitled event" : "Evento sin título",
     "Close" : "Cerrar",
     "This event was cancelled" : "Este evento fue cancelado",
-    "Title" : "Título",
-    "30 min" : "30 minutos",
     "Participants" : "Participantes",
     "Submit" : "Enviar",
     "Subscribe to {name}" : "Suscribirse a {name}",
@@ -513,6 +498,22 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "Mostrar accesos directos de teclado",
     "Successfully appended link to talk room to description." : "Enlace a la sala de Talk se agregó correctamente a la descripción.",
     "Error creating Talk room" : "Error al crear la sala de Talk",
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
+    "Event title" : "Título del evento",
+    "_time_::_times_" : ["hora","veces","veces"],
+    "Select to end repeat" : "Seleccionar para finalizar la repetición",
+    "from {formattedDate}" : "desde {formattedDate}",
+    "to {formattedDate}" : "hasta {formattedDate}",
+    "on {formattedDate}" : "el {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} a las {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "hasta {formattedDate} a las {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a las {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} a las {formattedTime}",
+    "Please enter a valid date" : "Ingresa una fecha válida",
+    "Please enter a valid date and time" : "Ingresa una fecha y hora válidas",
+    "Please select a time zone:" : "Selecciona una zona horaria:",
+    "Pick a time" : "Seleccionar una hora",
+    "Pick a date" : "Selecciona una fecha",
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
+    "30 min" : "30 minutos"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
