@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Citas",
     "Schedule appointment \"%s\"" : "Programar cita \"%s\"",
     "Schedule an appointment" : "Programar una cita",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Preparación para %s",
     "Follow up for %s" : "Seguimiento para %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Su cita \"%s\" con %s necesita confirmación",
@@ -63,6 +62,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "No se pudo copiar el enlace de la cita al portapapeles",
     "Preview" : "Previsualizar",
     "Copy link" : "Copiar liga",
+    "Duplicate" : "Duplicado",
     "Edit" : "Editar",
     "Delete" : "Borrar",
     "Appointment schedules" : "Cronograma de citas",
@@ -72,8 +72,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Habilitar calendario \"{calendar}\"",
     "Enable untitled calendar" : "Habilitar calendario sin título",
     "An error occurred, unable to change visibility of the calendar." : "Ocurrió un error, no se pudo cambiar la visibilidad del calendario.",
+    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
+    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
     "Untitled calendar" : "Calendario sin título",
     "Shared with you by" : "Compartido con Ud. por",
+    "Copy public link" : "Copiar enlace público",
     "Edit and share calendar" : "Editar y compartir calendario",
     "Edit calendar" : "Editar calendario",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dejando de compartir el calendario en {countdown} segundo","Dejando de compartir el calendario en {countdown} segundos","Dejando de compartir el calendario en {countdown} segundos"],
@@ -90,8 +93,6 @@ OC.L10N.register(
     "Creating subscription …" : "Creando suscripción …",
     "Add public holiday calendar" : "Añadir calendario público de días feriados",
     "Add custom public calendar" : "Añadir calendario público personalizado",
-    "Calendar link copied to clipboard." : "Enlace del calendario copiado al portapapeles.",
-    "Calendar link could not be copied to clipboard." : "No se pudo copiar el enlace del calendario al portapapeles.",
     "Copy subscription link" : "Copiar enlace de suscripción",
     "Copying link …" : "Copiando enlace …",
     "Copied link" : "Enlace copiado",
@@ -124,7 +125,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "No se pudo copiar el código embebido al portapapeles.",
     "Unpublishing calendar failed" : "No se pudo despublicar el calendario",
     "Share link" : "Compartir liga",
-    "Copy public link" : "Copiar enlace público",
     "Send link to calendar via email" : "Enviar enlace del calendario por correo electrónico",
     "Enter one address" : "Escriba una dirección",
     "Sending email …" : "Enviando correo electrónico …",
@@ -188,6 +188,7 @@ OC.L10N.register(
     "No reminder" : "Sin recordatorio",
     "Failed to save default calendar" : "No se pudo guardar el calendario predeterminado",
     "General" : "General",
+    "Default calendar for incoming invitations" : "Calendario predeterminado para aceptar invitaciones",
     "Appearance" : "Apariencia",
     "Editing" : "Editando",
     "Default reminder" : "Recordatorio predeterminado",
@@ -208,6 +209,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Crear cronograma de citas",
     "Edit appointment schedule" : "Editar cronograma de citas",
     "Update" : "Actualizar",
+    "(copy)" : "(copiar)",
     "Appointment name" : "Nombre de la cita",
     "Location" : "Ubicación",
     "Create a Talk room" : "Crear una sala de Talk",
@@ -317,6 +319,7 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Rechazar",
     "Tentative" : "Tentativo",
+    "Copied to clipboard" : "Copiado al portapapeles",
     "No attendees yet" : "Aún no hay asistentes",
     "Attendees" : "Asistentes",
     "Remove group" : "Eliminar grupo",
@@ -334,17 +337,14 @@ OC.L10N.register(
     "Make {label} the organizer and attend" : "Hacer que {label} sea el organizador y asistente",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Para enviar invitaciones y manejar respuestas, [linkopen]agregue su dirección de correo electrónico en la configuración personal[linkclose].",
     "Remove color" : "Eliminar color",
-    "Event title" : "Título del evento",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar la configuración de todo el día para eventos que forman parte de una serie recurrente.",
     "From" : "De",
     "To" : "Para",
     "Repeat" : "Repetir",
-    "_time_::_times_" : ["vez","veces","veces"],
     "never" : "nunca",
     "on date" : "en la fecha",
     "after" : "después",
     "End repeat" : "Terminar repetición",
-    "Select to end repeat" : "Seleccionar para terminar la repetición",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Este evento es la excepción a la recurrencia de una serie recurrente. No puede agregarle una regla de recurrencia.",
     "first" : "primero",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Los cambios en la regla de recurrencia sólo se aplicarán a ésta y a futuras ocurrencias.",
@@ -384,19 +384,6 @@ OC.L10N.register(
     "Maybe" : "Tal vez",
     "None" : "Ninguno",
     "Create" : "Crear",
-    "from {formattedDate}" : "desde {formattedDate}",
-    "to {formattedDate}" : "hasta {formattedDate}",
-    "on {formattedDate}" : "el {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} a las {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "hasta {formattedDate} a las {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a las {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} a las {formattedTime}",
-    "Please enter a valid date" : "Por favor, ingrese una fecha válida",
-    "Please enter a valid date and time" : "Por favor, ingresa una fecha y hora válidas",
-    "Select a time zone" : "Seleccionar la zona horaria",
-    "Please select a time zone:" : "Por favor, seleccione una zona horaria:",
-    "Pick a time" : "Elige una hora",
-    "Pick a date" : "Elige una fecha",
     "Type to search time zone" : "Escribir para buscar la zona horaria",
     "Global" : "Global",
     "Holidays in {region}" : "Días feriados en {region}",
@@ -430,7 +417,6 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se encontró la zona horaria configurada ({timezoneId}). Volviendo a UTC.\nPor favor, cambie su zona horaria en la configuración e informe de este problema.",
     "Edit event" : "Editar evento",
     "Event does not exist" : "El evento no existe",
-    "Duplicate" : "Duplicado",
     "Delete this occurrence" : "Eliminar esta ocurrencia",
     "Delete this and all future" : "Eliminar ésta y las futuras",
     "All day" : "Todo el día",
@@ -441,7 +427,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Adjunto que requiere acceso compartido","Adjuntos que requieren acceso compartido","Adjuntos que requieren acceso compartido"],
     "Untitled event" : "Evento sin título",
     "Close" : "Cerrar",
-    "30 min" : "30 min",
+    "This event was cancelled" : "Este evento fue cancelado",
     "Participants" : "Participantes",
     "Submit" : "Enviar",
     "Subscribe to {name}" : "Subscribir a {name}",
@@ -501,8 +487,8 @@ OC.L10N.register(
     "_+%n more_::_+%n more_" : ["+%n más","+%n más","+%n más"],
     "No events" : "No hay eventos",
     "Create a new event or change the visible time-range" : "Cree un nuevo evento o cambie el rango de horas visible",
-    "Failed to save event" : "No se pudo guardar el evento",
     "It might have been deleted, or there was a typo in a link" : "Puede que se haya eliminado o haya una errata en un enlace",
+    "Failed to save event" : "No se pudo guardar el evento",
     "It might have been deleted, or there was a typo in the link" : "Puede que se haya eliminado o haya una errata en el enlace",
     "Meeting room" : "Sala de juntas",
     "Lecture hall" : "Sala de conferencias",
@@ -535,6 +521,7 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
     "Appointment not found" : "Cita no encontrada",
     "User not found" : "No se encontró el usuario",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Oculto",
     "can edit" : "puede editar",
     "Calendar name …" : "Nombre del calendario …",
@@ -550,7 +537,6 @@ OC.L10N.register(
     "Show weekends" : "Mostrar fines de semana",
     "Show week numbers" : "Mostrar número de semana",
     "Time increments" : "Incrementos de tiempo",
-    "Default calendar for incoming invitations" : "Calendario predeterminado para aceptar invitaciones",
     "Copy primary CalDAV address" : "Copiar la dirección CalDAV principal",
     "Copy iOS/macOS CalDAV address" : "Copiar la dirección iOS/macOS CalDAV",
     "Personal availability settings" : "Configuración de disponibilidad personal",
@@ -560,6 +546,23 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "Se ha añadido correctamente el enlace a la sala de conversación a la descripción.",
     "Error creating Talk room" : "Error al crear la sala de Talk",
     "_%n more guest_::_%n more guests_" : ["%n invitado más","%n más invitados","%n más invitados"],
-    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos."
+    "Event title" : "Título del evento",
+    "_time_::_times_" : ["vez","veces","veces"],
+    "Select to end repeat" : "Seleccionar para terminar la repetición",
+    "from {formattedDate}" : "desde {formattedDate}",
+    "to {formattedDate}" : "hasta {formattedDate}",
+    "on {formattedDate}" : "el {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "desde {formattedDate} a las {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "hasta {formattedDate} a las {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "el {formattedDate} a las {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} a las {formattedTime}",
+    "Please enter a valid date" : "Por favor, ingrese una fecha válida",
+    "Please enter a valid date and time" : "Por favor, ingresa una fecha y hora válidas",
+    "Select a time zone" : "Seleccionar la zona horaria",
+    "Please select a time zone:" : "Por favor, seleccione una zona horaria:",
+    "Pick a time" : "Elige una hora",
+    "Pick a date" : "Elige una fecha",
+    "The visibility of this event in shared calendars." : "La visibilidad de este evento en calendarios compartidos.",
+    "30 min" : "30 min"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
