@@ -68,8 +68,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Enable calendar \"{calendar}\"",
     "Enable untitled calendar" : "Enable untitled calendar",
     "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
+    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
+    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
     "Untitled calendar" : "تقویم بدون عنوان",
     "Shared with you by" : "با شما به اشتراک گذاشته شده است",
+    "Copy public link" : "پیوند عمومی را کپی کنید",
     "Edit and share calendar" : "Edit and share calendar",
     "Edit calendar" : "ویرایش تقویم",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه","اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه ها"],
@@ -85,8 +88,6 @@ OC.L10N.register(
     "New subscription from link (read-only)" : "اشتراک جدید از پیوند (فقط خواندنی)",
     "Creating subscription …" : "ایجاد اشتراک…",
     "Add public holiday calendar" : "Add public holiday calendar",
-    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
-    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
     "Copy subscription link" : "پیوند اشتراک را کپی کنید",
     "Copying link …" : "کپی پیوند ...",
     "Copied link" : "پیوند کپی شد",
@@ -118,7 +119,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "کد جاسازی را نمی توان در کلیپ بورد کپی کرد.",
     "Unpublishing calendar failed" : "عدم انتشار تقویم موفقیت آمیز نبود",
     "Share link" : "لینک را به اشتراک بگذارید",
-    "Copy public link" : "پیوند عمومی را کپی کنید",
     "Send link to calendar via email" : "ارسال پیوند به تقویم از طریق ایمیل",
     "Enter one address" : "یک آدرس وارد کنید",
     "Sending email …" : "ارسال ایمیل…",
@@ -231,6 +231,7 @@ OC.L10N.register(
     "Select conversation" : "مکالمه را انتخاب کنید",
     "on" : "بر",
     "at" : "در",
+    "Amount" : "Amount",
     "before at" : "قبل از در",
     "Notification" : "اطلاع",
     "Email" : "ایمیل",
@@ -302,17 +303,15 @@ OC.L10N.register(
     "(organizer)" : "(تنظیم کننده)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose].",
     "Remove color" : "Remove color",
-    "Event title" : "عنوان رویداد",
+    "Title" : "Title",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Cannot modify all-day setting for events that are part of a recurrence-set.",
     "From" : "از",
     "To" : "به",
     "Repeat" : "تکرار",
-    "_time_::_times_" : ["بار","بارها"],
     "never" : "هرگز",
     "on date" : "در تاریخ",
     "after" : "بعد از",
     "End repeat" : "پایان تکرار ",
-    "Select to end repeat" : "برای پایان دادن به تکرار انتخاب کنید",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it.",
     "first" : "اولین",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "تغییر در قانون بازگشتی فقط در مورد این و همه وقایع آینده اعمال خواهد شد.",
@@ -352,18 +351,6 @@ OC.L10N.register(
     "Maybe" : "Maybe",
     "None" : "هیچ‌کدام",
     "Create" : "ایجاد",
-    "from {formattedDate}" : "از {formattedDate}",
-    "to {formattedDate}" : "به {formattedDate}",
-    "on {formattedDate}" : "در {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "از {formattedDate} در {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "به {formattedDate} در {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "در {formattedDate} در {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} در {formattedTime}",
-    "Please enter a valid date" : "لطفا یک تاریخ معتبر وارد کنید",
-    "Please enter a valid date and time" : "لطفاً یک تاریخ و زمان معتبر وارد کنید",
-    "Please select a time zone:" : "Please select a time zone:",
-    "Pick a time" : "Pick a time",
-    "Pick a date" : "Pick a date",
     "Type to search time zone" : "Type to search time zone",
     "Global" : "عمومی",
     "Holidays in {region}" : "Holidays in {region}",
@@ -403,8 +390,6 @@ OC.L10N.register(
     "Untitled event" : "رویداد بدون عنوان",
     "Close" : "بستن",
     "This event was cancelled" : "This event was cancelled",
-    "Title" : "Title",
-    "30 min" : "30 min",
     "Participants" : "شركت كنندگان",
     "Submit" : "ارسال",
     "Subscribe to {name}" : "اشتراک در {name}",
@@ -519,6 +504,22 @@ OC.L10N.register(
     "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
     "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
     "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
-    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک."
+    "Event title" : "عنوان رویداد",
+    "_time_::_times_" : ["بار","بارها"],
+    "Select to end repeat" : "برای پایان دادن به تکرار انتخاب کنید",
+    "from {formattedDate}" : "از {formattedDate}",
+    "to {formattedDate}" : "به {formattedDate}",
+    "on {formattedDate}" : "در {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "از {formattedDate} در {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "به {formattedDate} در {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "در {formattedDate} در {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} در {formattedTime}",
+    "Please enter a valid date" : "لطفا یک تاریخ معتبر وارد کنید",
+    "Please enter a valid date and time" : "لطفاً یک تاریخ و زمان معتبر وارد کنید",
+    "Please select a time zone:" : "Please select a time zone:",
+    "Pick a time" : "Pick a time",
+    "Pick a date" : "Pick a date",
+    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک.",
+    "30 min" : "30 min"
 },
 "nplurals=2; plural=(n > 1);");
