@@ -62,7 +62,9 @@ OC.L10N.register(
     "Accept" : "მიღება",
     "Decline" : "ურაყოფა",
     "Tentative" : "საცდელი",
+    "Copied to clipboard" : "კოპირებულია კლიპბორდში",
     "Attendees" : "დამსწრეები",
+    "Title" : "სათაური",
     "Repeat" : "გამეორება",
     "never" : "არასდროს",
     "after" : "შემდეგ",
@@ -77,7 +79,6 @@ OC.L10N.register(
     "Edit event" : "მოვლენის ცვლილება",
     "All day" : "მთელი დღე",
     "Close" : "დახურვა",
-    "Title" : "სათაური",
     "Participants" : "მონაწილეები",
     "Submit" : "გაგზავნა",
     "Anniversary" : "დაბადების დღე",
@@ -93,7 +94,6 @@ OC.L10N.register(
     "Categories" : "კატეგორიები",
     "Hidden" : "უჩინარი",
     "can edit" : "შეგიძლია შეცვლა",
-    "Show week numbers" : "კვირის ნომრების ჩვენება",
-    "Keyboard shortcuts" : "კლავიატურის კომბინაციები"
+    "Show week numbers" : "კვირის ნომრების ჩვენება"
 },
 "nplurals=2; plural=(n!=1);");
