@@ -189,6 +189,7 @@ OC.L10N.register(
     "No reminder" : "Ingen påminnelse",
     "Failed to save default calendar" : "Lagring av standard kalender feilet",
     "General" : "Generell",
+    "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
     "Appearance" : "Utseende",
     "Editing" : "Rediger",
     "Default reminder" : "Standardpåminnelse",
@@ -245,6 +246,7 @@ OC.L10N.register(
     "Select conversation" : "Velg samtale",
     "on" : "på",
     "at" : "ved",
+    "Amount" : "Mengde",
     "before at" : "før ved",
     "Notification" : "Varsel",
     "Email" : "E-post",
@@ -332,17 +334,15 @@ OC.L10N.register(
     "Make {label} the organizer and attend" : "Gjør {label} til organisatoren og delta",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "For å sende ut invitasjoner og håndtere svar, [linkopen]legg til e-postadressen din i personlige innstillinger[linkclose].",
     "Remove color" : "Fjern farge",
-    "Event title" : "Tittel på hendelsen",
+    "Title" : "Navn",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Kan ikke endre \"hel dag\"-innstillingen for hendelser som er en del av et gjentakelsessett.",
     "From" : "Fra",
     "To" : "Til",
     "Repeat" : "Gjenta",
-    "_time_::_times_" : ["gang","ganger"],
     "never" : "aldri",
     "on date" : "på dato",
     "after" : "etter",
     "End repeat" : "Avslutt gjentakelse",
-    "Select to end repeat" : "Velg for å avslutte gjentakelse",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Denne hendelsen er gjentakelsesunntaket for et gjentakelsessett. Du kan ikke legge til en gjentakelsesregel til den.",
     "first" : "første",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Endringer i gjentakelsesregelen vil kun gjelde for denne og alle fremtidige hendelser.",
@@ -384,19 +384,6 @@ OC.L10N.register(
     "Maybe" : "Kanskje",
     "None" : "Ingen",
     "Create" : "Opprett",
-    "from {formattedDate}" : "fra {formattedDate}",
-    "to {formattedDate}" : "til {formattedDate}",
-    "on {formattedDate}" : "den {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} kl. {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "til {formattedDate} kl. {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "den {formattedDate} kl. {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
-    "Please enter a valid date" : "Vennligst tast inn en gyldig dato",
-    "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og et tidspunkt",
-    "Select a time zone" : "Velg en tidssone",
-    "Please select a time zone:" : "Vennligst velg en tidssone:",
-    "Pick a time" : "Velg et tidspunkt",
-    "Pick a date" : "Velg en dato",
     "Type to search time zone" : "Skriv for å søke etter tidssone",
     "Global" : "Global",
     "Holidays in {region}" : "Helligdager i {region}",
@@ -442,8 +429,6 @@ OC.L10N.register(
     "Untitled event" : "Hendelse uten tittel",
     "Close" : "Lukk",
     "This event was cancelled" : "Denne hendelsen ble kansellert",
-    "Title" : "Navn",
-    "30 min" : "30 min",
     "Participants" : "Deltakere",
     "Submit" : "Send inn",
     "Subscribe to {name}" : "Abonner på {name}",
@@ -503,8 +488,8 @@ OC.L10N.register(
     "_+%n more_::_+%n more_" : ["+%n mer","+%n mer"],
     "No events" : "Ingen hendelser",
     "Create a new event or change the visible time-range" : "Opprett en ny hendelse eller endre på valgt tidsrom",
-    "Failed to save event" : "Lagring av hendelse feilet",
     "It might have been deleted, or there was a typo in a link" : "Det kan ha blitt slettet, eller det var en skrivefeil i en lenke",
+    "Failed to save event" : "Lagring av hendelse feilet",
     "It might have been deleted, or there was a typo in the link" : "Det kan ha blitt slettet, eller det var en skrivefeil i lenken",
     "Meeting room" : "Møterom",
     "Lecture hall" : "Forelesningssal",
@@ -554,7 +539,6 @@ OC.L10N.register(
     "Show weekends" : "Vis helger",
     "Show week numbers" : "Vis ukenummer",
     "Time increments" : "Tidsøkninger",
-    "Default calendar for incoming invitations" : "Standard kalender for innkommende invitasjoner",
     "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
     "Copy iOS/macOS CalDAV address" : "Kopier CalDAV-lenke for iOS/macOS",
     "Personal availability settings" : "Personlig ledighets-innstillinger",
@@ -564,6 +548,23 @@ OC.L10N.register(
     "Successfully appended link to talk room to description." : "La til lenke til Talk-rom til beskrivelsen.",
     "Error creating Talk room" : "Feil ved opprettelse av Talk-rom",
     "_%n more guest_::_%n more guests_" : ["%n gjest til","%n flere gjester"],
-    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere"
+    "Event title" : "Tittel på hendelsen",
+    "_time_::_times_" : ["gang","ganger"],
+    "Select to end repeat" : "Velg for å avslutte gjentakelse",
+    "from {formattedDate}" : "fra {formattedDate}",
+    "to {formattedDate}" : "til {formattedDate}",
+    "on {formattedDate}" : "den {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "fra {formattedDate} kl. {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "til {formattedDate} kl. {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "den {formattedDate} kl. {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} kl. {formattedTime}",
+    "Please enter a valid date" : "Vennligst tast inn en gyldig dato",
+    "Please enter a valid date and time" : "Vennligst tast inn en gyldig dato og et tidspunkt",
+    "Select a time zone" : "Velg en tidssone",
+    "Please select a time zone:" : "Vennligst velg en tidssone:",
+    "Pick a time" : "Velg et tidspunkt",
+    "Pick a date" : "Velg en dato",
+    "The visibility of this event in shared calendars." : "Synlighet for denne oppføringen i delte kalendere",
+    "30 min" : "30 min"
 },
 "nplurals=2; plural=(n != 1);");
