@@ -21,7 +21,6 @@ OC.L10N.register(
     "Appointments" : "Sestanki",
     "Schedule appointment \"%s\"" : "Načrtovanje sestanka »%s«",
     "Schedule an appointment" : "Načrtovanje sestanka",
-    "%1$s - %2$s" : "%1$s – %2$s",
     "Prepare for %s" : "Pripravi za %s",
     "Follow up for %s" : "Nadaljevanje za %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Sestanek »%s« z osebo %s zahteva potrditev",
@@ -61,6 +60,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Povezave sestanka ni mogoče kopirati v odložišče.",
     "Preview" : "Predogled",
     "Copy link" : "Kopiraj povezavo",
+    "Duplicate" : "Podvoji",
     "Edit" : "Uredi",
     "Delete" : "Izbriši",
     "Create new" : "Ustvari novo",
@@ -69,8 +69,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Omogoči koledar »{calendar}«",
     "Enable untitled calendar" : "Omogoči neimenovan koledar",
     "An error occurred, unable to change visibility of the calendar." : "Prišlo je do napake; ni mogoče spremeniti vidnosti koledarja.",
+    "Calendar link copied to clipboard." : "Povezava koledarja je kopirana v odložišče.",
+    "Calendar link could not be copied to clipboard." : "Povezave koledarja ni mogoče kopirati v odložišče.",
     "Untitled calendar" : "Neimenovan koledar",
     "Shared with you by" : "Souporabo omogoča",
+    "Copy public link" : "Kopiraj javno povezavo",
     "Edit and share calendar" : "Uredi in omogoči souporabo koledarja",
     "Edit calendar" : "Uredi koledar",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Souporaba koledarja bo onemogočena čez {countdown} sekundo","Souporaba koledarja bo onemogočena čez {countdown} sekundi","Souporaba koledarja bo onemogočena čez {countdown} sekunde","Souporaba koledarja bo prekinjena čez {countdown} sekund"],
@@ -87,8 +90,6 @@ OC.L10N.register(
     "Creating subscription …" : "Poteka ustvarjanje naročnine ...",
     "Add public holiday calendar" : "Dodaj koledar javnih praznikov",
     "Add custom public calendar" : "Dodaj javni koledar po meri",
-    "Calendar link copied to clipboard." : "Povezava koledarja je kopirana v odložišče.",
-    "Calendar link could not be copied to clipboard." : "Povezave koledarja ni mogoče kopirati v odložišče.",
     "Copy subscription link" : "Kopiraj povezavo naročnine",
     "Copying link …" : "Kopiranje povezave ...",
     "Copied link" : "Kopirana povezava",
@@ -121,7 +122,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Vstavljive kode ni mogoče kopirati v odložišče.",
     "Unpublishing calendar failed" : "Preklic objave koledarja je spodletel",
     "Share link" : "Povezava za souporabo",
-    "Copy public link" : "Kopiraj javno povezavo",
     "Send link to calendar via email" : "Pošlji povezavo za koledar prek elektronske pošte",
     "Enter one address" : "Vpišite en naslov",
     "Sending email …" : "Poteka pošiljanje elektronske pošte ...",
@@ -185,6 +185,7 @@ OC.L10N.register(
     "No reminder" : "Brez opomnika",
     "Failed to save default calendar" : "Shranjevanje privzetega koledarja je spodletelo",
     "General" : "Splošno",
+    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
     "Appearance" : "Videz",
     "Editing" : "Urejanje",
     "Default reminder" : "Privzeti opomnik",
@@ -200,6 +201,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "Javno – prikazano na strani profila",
     "Private – only accessible via secret link" : "Zasebno – dostopno le z zasebno povezavo",
     "Update" : "Posodobi",
+    "(copy)" : "(kopija)",
     "Appointment name" : "Ime srečanja",
     "Location" : "Mesto",
     "Create a Talk room" : "Ustvari skupino Talk",
@@ -239,6 +241,7 @@ OC.L10N.register(
     "Select conversation" : "pogovora",
     "on" : "na",
     "at" : "ob",
+    "Amount" : "Količina",
     "before at" : "prej ob",
     "Notification" : "Obvestilo",
     "Email" : "Elektronsko sporočilo",
@@ -304,6 +307,7 @@ OC.L10N.register(
     "Accept" : "Sprejmi",
     "Decline" : "Zavrni",
     "Tentative" : "V usklajevanju",
+    "Copied to clipboard" : "Kopirano v odložišče",
     "No attendees yet" : "Ni še vpisanih udeležencev",
     "Attendees" : "Udeleženci",
     "Remove group" : "Odstrani skupino",
@@ -317,17 +321,15 @@ OC.L10N.register(
     "(organizer)" : " (skliče dogodek)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Za pošiljanje vabil in urejanje odzivov mora biti [linkopen]vaš elektronski naslov vpisan med osebnimi nastavitvami[linkclose].",
     "Remove color" : "Odstrani barvo",
-    "Event title" : "Naslov dogodka",
+    "Title" : "Naslov",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Ni mogoče spremeniti nastavitve »celodnevno« za dogodke, ki so opredeljeni kot ponavljajoči.",
     "From" : "Od",
     "To" : "Za",
     "Repeat" : "Ponovi",
-    "_time_::_times_" : [" ponovitvi"," ponovitvah"," ponovitvah"," ponovitvah"],
     "never" : "nikoli",
     "on date" : "na dan",
     "after" : "po",
     "End repeat" : "Končaj:",
-    "Select to end repeat" : "Izbor končanja ponavljanja",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Ta dogodek ima vpisano izjemo ponavljanja, zato pravila ponovitve ni mogoče dodati.",
     "first" : "1.",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Spremembe ponavljajočega dogodka bodo uveljavljene za to in vse prihodnje ponovitve.",
@@ -369,19 +371,6 @@ OC.L10N.register(
     "Maybe" : "Morda",
     "None" : "Brez",
     "Create" : "Ustvari",
-    "from {formattedDate}" : "od {formattedDate}",
-    "to {formattedDate}" : "do {formattedDate}",
-    "on {formattedDate}" : "na {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "od {formattedDate} ob {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "do {formattedDate} ob {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "na {formattedDate} ob {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} ob {formattedTime}",
-    "Please enter a valid date" : "Vpisati je treba veljaven datum",
-    "Please enter a valid date and time" : "Vpisati je treba veljaven datum in čas",
-    "Select a time zone" : "Izbor časovnega pasu",
-    "Please select a time zone:" : "Izbor časovnega pasu:",
-    "Pick a time" : "Izbor časa",
-    "Pick a date" : "Izbor datuma",
     "Type to search time zone" : "Vpišite niz za iskanje časovnega pasu",
     "Global" : "Splošno",
     "Holidays in {region}" : "Prazniki v regiji {region}",
@@ -410,9 +399,9 @@ OC.L10N.register(
     "Personal" : "Osebno",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Samodejno zaznavanje časovnega pasu določa časovni pas kot UTC.\nTo je najverjetneje prilagojeno na varnostne nastavitve spletnega brskalnika.\nČasovni pas lahko določite tudi ročno med nastavitvami koledarja.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Nastavljenega časovnega pasu ({timezoneId}) ni mogoče najti. Povrnjena bo nastavitev na UTC.\nČasovni pas določite ročno med nastavitvami koledarja in pošljite poročilo o napaki.",
+    "Discard changes" : "Opusti spremembe",
     "Edit event" : "Uredi dogodek",
     "Event does not exist" : "Dogodek ne obstaja",
-    "Duplicate" : "Podvoji",
     "Delete this occurrence" : "Izbriši to pojavitev",
     "Delete this and all future" : "Izbriši to in vse prihodnje pojavitve",
     "All day" : "Ves dan",
@@ -421,9 +410,8 @@ OC.L10N.register(
     "Invite" : "Povabi",
     "Untitled event" : "Neimenovan dogodek",
     "Close" : "Zapri",
+    "This event was cancelled" : "Dogodek je preklican",
     "Selected" : "Izbrano",
-    "Title" : "Naslov",
-    "30 min" : "30 min",
     "Participants" : "Udeleženci",
     "Submit" : "Pošlji",
     "Subscribe to {name}" : "Naroči na {name}",
@@ -515,6 +503,7 @@ OC.L10N.register(
     "This is an event reminder." : "To je opomnik dogodka.",
     "Appointment not found" : "Sestanka ni mogoče najti",
     "User not found" : "Uporabnika ni mogoče najti",
+    "%1$s - %2$s" : "%1$s – %2$s",
     "Hidden" : "Skrito",
     "can edit" : "lahko ureja",
     "Calendar name …" : "Ime koledarja …",
@@ -530,14 +519,29 @@ OC.L10N.register(
     "Show weekends" : "Pokaži vikende",
     "Show week numbers" : "Pokaži številke tednov",
     "Time increments" : "Časovno povečevanje",
-    "Default calendar for incoming invitations" : "Privzeti koledar za prihajajoča povabila",
     "Copy primary CalDAV address" : "Kopiraj osnovni naslov CalDAV",
     "Copy iOS/macOS CalDAV address" : "Kopiraj naslov CalDAV za iOS/macOS",
     "Personal availability settings" : "Nastavitve osebne dejavnosti",
     "Show keyboard shortcuts" : "Pokaži tipkovne bližnjice",
     "Successfully appended link to talk room to description." : "Povezava do sobe Talk je uspešno dodana v opis.",
     "Error creating Talk room" : "Prišlo je do napake med ustvarjanjem klepetalnice Talk",
+    "Event title" : "Naslov dogodka",
+    "_time_::_times_" : [" ponovitvi"," ponovitvah"," ponovitvah"," ponovitvah"],
+    "Select to end repeat" : "Izbor končanja ponavljanja",
+    "from {formattedDate}" : "od {formattedDate}",
+    "to {formattedDate}" : "do {formattedDate}",
+    "on {formattedDate}" : "na {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "od {formattedDate} ob {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "do {formattedDate} ob {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "na {formattedDate} ob {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} ob {formattedTime}",
+    "Please enter a valid date" : "Vpisati je treba veljaven datum",
+    "Please enter a valid date and time" : "Vpisati je treba veljaven datum in čas",
+    "Select a time zone" : "Izbor časovnega pasu",
+    "Please select a time zone:" : "Izbor časovnega pasu:",
+    "Pick a time" : "Izbor časa",
+    "Pick a date" : "Izbor datuma",
     "The visibility of this event in shared calendars." : "Vidnost tega dogodka v koledarjih v souporabi.",
-    "Keyboard shortcuts" : "Tipkovne bližnjice"
+    "30 min" : "30 min"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
