@@ -61,7 +61,7 @@ class ContactController extends Controller {
 			return new JSONResponse();
 		}
 
-		$result = $this->contactsManager->search($search, ['FN', 'ADR']);
+		$result = $this->contactsManager->search($search, ['FN', 'ADR'], ['enumeration' => false]);
 
 		$contacts = [];
 		foreach ($result as $r) {
@@ -161,7 +161,7 @@ class ContactController extends Controller {
 			return new JSONResponse();
 		}
 
-		$groupmembers = $this->contactsManager->search($groupName, ['CATEGORIES']);
+		$groupmembers = $this->contactsManager->search($groupName, ['CATEGORIES'], ['enumeration' => false]);
 		$contacts = [];
 		foreach ($groupmembers as $r) {
 			if (!in_array($groupName, explode(',', $r['CATEGORIES']), true)) {
@@ -262,7 +262,7 @@ class ContactController extends Controller {
 			return new JSONResponse([], Http::STATUS_NOT_FOUND);
 		}
 
-		$result = $this->contactsManager->search($search, ['EMAIL']);
+		$result = $this->contactsManager->search($search, ['EMAIL'], ['enumeration' => false]);
 
 		foreach ($result as $r) {
 			if (!$this->contactsService->hasEmail($r) || $this->contactsService->isSystemBook($r)) {
